netapp_ontap.models.svm_ldap API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.svm_ldap`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SvmLdapSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SvmLdap object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ad_domain GET POST PATCH`

    This parameter specifies the name of the Active Directory domain used to discover LDAP servers for use by this client. This is mutually exclusive with `servers` during POST.

  `base_dn GET POST PATCH`

    Specifies the default base DN for all searches.

  `bind_dn GET POST PATCH`

    Specifies the user that binds to the LDAP servers. SVM API supports anonymous binding. For Simple and SASL LDAP binding, use the LDAP API endpoint.

  `enabled GET POST PATCH`

    Enable LDAP? Setting to true creates a configuration if not already created.

  `servers GET POST PATCH`

    The servers field of the svm_ldap.